.. currentmodule:: sardana.pool.poolaction

:mod:`~sardana.pool.poolaction`
======================================

.. automodule:: sardana.pool.poolaction

.. rubric:: Functions

.. hlist::
    :columns: 3

    * :func:`get_thread_pool`

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`PoolAction`
    * :class:`OperationInfo`
    * :class:`PoolActionItem`
    * :class:`ActionContext`
     
.. autofunction:: get_thread_pool

PoolAction
-------------------

.. inheritance-diagram:: PoolAction
    :parts: 1
    
.. autoclass:: PoolAction
    :show-inheritance:
    :members:
    :undoc-members:
    
OperationInfo
-------------------

.. inheritance-diagram:: OperationInfo
    :parts: 1
    
.. autoclass:: OperationInfo
    :show-inheritance:
    :members:
    :undoc-members:

PoolActionItem
-------------------

.. inheritance-diagram:: PoolActionItem
    :parts: 1
    
.. autoclass:: PoolActionItem
    :show-inheritance:
    :members:
    :undoc-members:

ActionContext
-------------------

.. inheritance-diagram:: ActionContext
    :parts: 1
    
.. autoclass:: ActionContext
    :show-inheritance:
    :members:
    :undoc-members:
